@@ -1,4 +1,4 @@
-# Copyright (c) 2018, Matt Layman and contributors
+# Copyright (c) 2019, Matt Layman and contributors
 
 import argparse
 import os
@@ -18,8 +18,8 @@ class TestMain(TestCase):
 
     def test_exits_with_error(self):
         """The main function returns an error status if there were failures."""
-        argv = ['/bin/fake', 'fake.tap']
-        stream = open(os.devnull, 'w')
+        argv = ["/bin/fake", "fake.tap"]
+        stream = open(os.devnull, "w")
 
         status = main(argv, stream=stream)
 
@@ -30,7 +30,7 @@ class TestMain(TestCase):
         result.wasSuccessful.return_value = True
         self.assertEqual(0, get_status(result))
 
-    @mock.patch.object(Loader, 'load_suite_from_stdin')
+    @mock.patch.object(Loader, "load_suite_from_stdin")
     def test_build_suite_from_stdin(self, load_suite_from_stdin):
         args = mock.Mock()
         args.files = []
@@ -39,20 +39,20 @@ class TestMain(TestCase):
         suite = build_suite(args)
         self.assertEqual(expected_suite, suite)
 
-    @mock.patch.object(Loader, 'load_suite_from_stdin')
+    @mock.patch.object(Loader, "load_suite_from_stdin")
     def test_build_suite_from_stdin_dash(self, load_suite_from_stdin):
-        argv = ['/bin/fake', '-']
+        argv = ["/bin/fake", "-"]
         args = parse_args(argv)
         expected_suite = mock.Mock()
         load_suite_from_stdin.return_value = expected_suite
         suite = build_suite(args)
         self.assertEqual(expected_suite, suite)
 
-    @mock.patch('tap.main.sys.stdin')
-    @mock.patch('tap.main.sys.exit')
-    @mock.patch.object(argparse.ArgumentParser, 'print_help')
+    @mock.patch("tap.main.sys.stdin")
+    @mock.patch("tap.main.sys.exit")
+    @mock.patch.object(argparse.ArgumentParser, "print_help")
     def test_when_no_pipe_to_stdin(self, print_help, sys_exit, mock_stdin):
-        argv = ['/bin/fake']
+        argv = ["/bin/fake"]
         mock_stdin.isatty = mock.Mock(return_value=True)
         parse_args(argv)
         self.assertTrue(print_help.called)
